@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11700 2019-09-05 08:49:19Z Lavender $
+# $Id: __init__.py 11713 2019-09-18 13:42:53Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-05 16:49:19 +0800 (週四, 05 九月 2019) $
-# $Revision: 11700 $
+# $Date: 2019-09-18 22:42:53 +0900 (週三, 18 九月 2019) $
+# $Revision: 11713 $
 #
 # Contributors:
 #  Bear (original author)
 #  Yachu
 
+from Iuno.Util import update
+
 from Iuppiter.DjangoUtil import (
     extendInstalledApps, extendMiddlewareClasses)
 
@@ -46,4 +48,11 @@ def attachSettings(settingsLocals, backends, preferred, config):
     extendMiddlewareClasses(settingsLocals, [
         'django_statsd.middleware.StatsdMiddlewareTimer',
     ])
+    
+    DEFAULT_STATSD_SETTINGS = {
+        'STATSD_HOST': "statsd.nuwainfo.com",
+        "STATSD_PORT": 8125,
+    }
+    
+    update(settingsLocals, DEFAULT_STATSD_SETTINGS)
 
