@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11708 2019-09-17 15:52:15Z Lavender $
+# $Id: forms.py 11715 2019-09-18 14:34:08Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-17 23:52:15 +0800 (週二, 17 九月 2019) $
-# $Revision: 11708 $
+# $Date: 2019-09-18 23:34:08 +0900 (週三, 18 九月 2019) $
+# $Revision: 11715 $
 
 import os
 import hashlib
@@ -69,6 +69,7 @@ catalogueViews.ProductCreateUpdateView.form_class = ProductForm
 
 # content block ckeditor
 if not VERSION >= (2, 0, 0):
+    # RawHTMLForm
     promotionsViews = get_class('dashboard.promotions', 'views')
 
     RawHTML = get_model('promotions', 'RawHTML')
@@ -95,6 +96,38 @@ if not VERSION >= (2, 0, 0):
                 
     promotionsViews.CreateRawHTMLView.form_class = RawHTMLForm
     promotionsViews.UpdateRawHTMLView.form_class = RawHTMLForm
+else:
+    # RawHTMLForm
+    pass
+    
+# Pages
+pagesViews = get_class('dashboard.pages', 'views')
+
+FlatPage = get_model('flatpages', 'FlatPage')
+_PageUpdateForm = get_class('dashboard.pages.forms', 'PageUpdateForm')
+
+class PageUpdateForm(_PageUpdateForm):
+    class Meta(_PageUpdateForm.Meta):
+        model = FlatPage
+        fields = ('title', 'url', 'content')
+        
+        if hasattr(settings, 'IUNO_SHOP_PAGE_CKEDITOR'):
+            if settings.IUNO_SHOP_CONTENT_BLOCK_CKEDITOR:
+                widgets = {
+                    'content': CKEditorUploadingWidget(),
+                }
+            else:
+                widgets = {
+                    'content': forms.Textarea(attrs={'class': 'wysiwyg'}),
+                }
+        else:
+            widgets = {
+                'content': forms.Textarea(attrs={'class': 'wysiwyg'}),
+            }
+            
+pagesViews.PageCreateView.form_class = PageUpdateForm
+pagesViews.PageUpdateView.form_class = PageUpdateForm
+
 
 if VERSION >= (2, 0, 0):
     # option type
